@@ -9,6 +9,7 @@ from feeluown.gui.base_renderer import LibraryTabRendererMixin
 from feeluown.gui.page_containers.table import Renderer
 from feeluown.gui.widgets.tabbar import Tab
 
+from fuo_netease import provider
 
 logger = logging.getLogger(__name__)
 
@@ -17,17 +18,18 @@ async def render(req, **kwargs):
     app = req.ctx['app']
     app.ui.right_panel.set_body(app.ui.table_container)
 
-    provider = app.library.get('netease')
     tab_id = Tab(int(req.query.get('tab_id', Tab.songs.value)))
     # FIXM
-    renderer = FavRenderer(tab_id, provider._user)
+    renderer = FavRenderer(tab_id)
     await app.ui.table_container.set_renderer(renderer)
 
 
 class FavRenderer(Renderer, LibraryTabRendererMixin):
-    def __init__(self, tab_id, user):
+    def __init__(self, tab_id):
+        global provider
+
         self.tab_id = tab_id
-        self._user = user
+        self._user = provider._user
 
     async def render(self):
         self.render_tabbar()
@@ -35,7 +37,7 @@ class FavRenderer(Renderer, LibraryTabRendererMixin):
         self.meta_widget.title = '收藏与关注'
 
         if self.tab_id == Tab.songs:
-            self.show_songs(await aio.run_fn(lambda: self._user.cloud_songs))
+            self.show_songs(await aio.run_fn(provider.current_user_cloud_songs))
             dir_upload_btn = TextButton('上传目录', self.toolbar)
             dir_upload_btn.clicked.connect(
                 lambda: aio.run_afn(self._upload_cloud_songs_bydir))
@@ -47,11 +49,12 @@ class FavRenderer(Renderer, LibraryTabRendererMixin):
             refresh_btn.clicked.connect(self._refresh_cloud_songs)
             self.toolbar.add_tmp_button(refresh_btn)
         elif self.tab_id == Tab.albums:
-            self.show_albums(await aio.run_fn(lambda: self._user.fav_albums))
+            self.show_albums(await aio.run_fn(provider.current_user_fav_albums))
         elif self.tab_id == Tab.artists:
-            self.show_artists(await aio.run_fn(lambda: self._user.fav_artists))
+            self.show_artists(await aio.run_fn(provider.current_user_fav_artists))
         elif self.tab_id == Tab.playlists:
-            self.show_playlists(await aio.run_fn(lambda: self._user.fav_djradio))
+            playlists = await aio.run_fn(provider.current_user_fav_djradios)
+            self.show_playlists(playlists)
 
     async def _upload_cloud_songs_bydir(self):
         # FIXME: 目前无法根据当前页面进行自动刷新, 只能手动刷新
@@ -95,7 +98,6 @@ class FavRenderer(Renderer, LibraryTabRendererMixin):
         QMessageBox.information(self.toolbar, '上传音乐', '上传完成！')
 
     def _refresh_cloud_songs(self):
-        self._user.cloud_songs = None
         self.show_by_tab_id(Tab.songs)
 
     def show_by_tab_id(self, tab_id):
