@@ -16,6 +16,7 @@ from marshmallow import Schema, post_load, fields, EXCLUDE
 from feeluown.library import (
     SongModel, BriefAlbumModel, BriefArtistModel, ModelState, BriefSongModel,
     VideoModel, AlbumModel, ArtistModel, PlaylistModel, BriefUserModel,
+    SimpleSearchResult,
 )
 from feeluown.media import Quality, MediaType, Media
 
@@ -31,6 +32,7 @@ class BaseSchema(Schema):
 
 Schema = BaseSchema
 Unknown = 'Unknown'
+DjradioPrefix = 'djradio_'
 
 
 def create_model(model_cls, data, fields_to_cache=None):
@@ -154,6 +156,7 @@ class V2AlbumSchema(Schema):
     artists = fields.List(fields.Nested('V2BriefArtistSchema'))
     # 收藏和搜索接口返回的 album 数据中的 songs 为 None
     songs = fields.List(fields.Nested('V2SongSchema'), allow_none=True)
+    song_count = fields.Int(data_key='size')
 
     # Description is fetched seperatelly by `album_desc` API.
     description = fields.Str(missing='')
@@ -166,6 +169,7 @@ class V2AlbumSchema(Schema):
             released_date = datetime.fromtimestamp(released / 1000)
             released_str = released_date.strftime('%Y-%m-%d')
             data['released'] = released_str
+        data['songs'] = data['songs'] or []
         return AlbumModel(**data)
 
 
@@ -204,12 +208,15 @@ class NAlbumSchemaV3(Schema):
 class NeteaseDjradioSchema(Schema):
     identifier = fields.Int(required=True, data_key='id')
     name = fields.Str(required=True)
-    desc = fields.Str(required=False)
+    description = fields.Str(data_key='desc', required=False)
     cover = fields.Str(required=False, data_key='picUrl')
 
     @post_load
     def create_model(self, data, **kwargs):
-        return NRadioModel(**data)
+        identifier = data['identifier']
+        data['identifier'] = f'{DjradioPrefix}{identifier}'
+        # TODO: set creator properly.
+        return PlaylistModel(**data, creator=None)
 
 
 class NDjradioSchema(Schema):
@@ -286,32 +293,15 @@ class V2PlaylistSchema(Schema):
         return PlaylistModel(**data)
 
 
-class NeteaseUserSchema(Schema):
-    identifier = fields.Int(required=True, data_key='id')
-    name = fields.Str(required=True)
-    playlists = fields.List(fields.Nested(V2PlaylistSchema))
-    fav_playlists = fields.List(fields.Nested(V2PlaylistSchema))
-    cookies = fields.Dict()
-
-    @post_load
-    def create_model(self, data, **kwargs):
-        return NUserModel(**data)
-
-
 class NeteaseSearchSchema(Schema):
     """搜索结果 Schema"""
+    q = fields.Str()
     songs = fields.List(fields.Nested(V2SongSchema))
-    albums = fields.List(fields.Nested(V2BriefAlbumSchema))
+    albums = fields.List(fields.Nested(V2AlbumSchema))
     artists = fields.List(fields.Nested(V2BriefArtistSchema))
     playlists = fields.List(fields.Nested(V2PlaylistSchema))
 
     @post_load
     def create_model(self, data, **kwargs):
-        return NSearchModel(**data)
-
-
-from .models import (  # noqa
-    NUserModel,
-    NSearchModel,
-    NRadioModel,
-)  # noqa
+        data.pop('source')
+        return SimpleSearchResult(**data)
